package com.sun.media.sound;

import java.util.Iterator;
import javax.sound.midi.Patch;
import java.util.Arrays;
import java.util.ArrayList;
import javax.sound.midi.Instrument;
import javax.sound.midi.SoundbankResource;
import java.util.List;
import javax.sound.midi.Soundbank;

public class SimpleSoundbank implements Soundbank
{
    String name;
    String version;
    String vendor;
    String description;
    List<SoundbankResource> resources;
    List<Instrument> instruments;
    
    public SimpleSoundbank() {
        this.name = "";
        this.version = "";
        this.vendor = "";
        this.description = "";
        this.resources = new ArrayList();
        this.instruments = new ArrayList();
    }
    
    @Override
    public String getName() {
        return this.name;
    }
    
    @Override
    public String getVersion() {
        return this.version;
    }
    
    @Override
    public String getVendor() {
        return this.vendor;
    }
    
    @Override
    public String getDescription() {
        return this.description;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    public void setVendor(String vendor) {
        this.vendor = vendor;
    }
    
    public void setVersion(String version) {
        this.version = version;
    }
    
    @Override
    public SoundbankResource[] getResources() {
        return (SoundbankResource[])this.resources.toArray(new SoundbankResource[this.resources.size()]);
    }
    
    @Override
    public Instrument[] getInstruments() {
        Instrument[] a = (Instrument[])this.instruments.toArray(new Instrument[this.resources.size()]);
        Arrays.sort(a, new ModelInstrumentComparator());
        return a;
    }
    
    @Override
    public Instrument getInstrument(Patch patch) {
        int program = patch.getProgram();
        int bank = patch.getBank();
        int percussion = 0;
        if ((patch instanceof ModelPatch)) {
            percussion = ((ModelPatch)patch).isPercussion();
        }
        for (Instrument instrument : this.instruments) {
            Patch patch2 = instrument.getPatch();
            int program2 = patch2.getProgram();
            int bank2 = patch2.getBank();
            if (program == program2 && bank == bank2) {
                int percussion2 = 0;
                if ((patch2 instanceof ModelPatch)) {
                    percussion2 = ((ModelPatch)patch2).isPercussion();
                }
                if (percussion == percussion2) {
                    return instrument;
                }
                continue;
            }
            else {
                continue;
            }
        }
        return null;
    }
    
    public void addResource(SoundbankResource soundbankResource) {
        if ((soundbankResource instanceof Instrument)) {
            this.instruments.add((Instrument)soundbankResource);
        }
        else {
            this.resources.add(soundbankResource);
        }
    }
    
    public void removeResource(SoundbankResource soundbankResource) {
        if ((soundbankResource instanceof Instrument)) {
            this.instruments.remove((SoundbankResource)soundbankResource);
        }
        else {
            this.resources.remove(soundbankResource);
        }
    }
    
    public void addInstrument(Instrument instrument) {
        this.instruments.add(instrument);
    }
    
    public void removeInstrument(Instrument instrument) {
        this.instruments.remove(instrument);
    }
    
    public void addAllInstruments(Soundbank soundbank) {
        Instrument[] instruments = soundbank.getInstruments();
        for (int length = instruments.length, i = 0; i < length; ++i) {
            this.addInstrument(instruments[i]);
        }
    }
    
    public void removeAllInstruments(Soundbank soundbank) {
        Instrument[] instruments = soundbank.getInstruments();
        for (int length = instruments.length, i = 0; i < length; ++i) {
            this.removeInstrument(instruments[i]);
        }
    }
}
